.. Abjad documentation master file, created by
    sphinx-quickstart on Tue Apr 14 22:09:19 2009.
    You can adapt this file completely to your liking, 
    but it should at least contain the root `toctree` directive.

Welcome to Abjad (|release|)
=============================

Abjad helps composers build up complex pieces of music notation
in an iterative and incremental way. 
Use Abjad to create a symbolic representation of all the notes, 
rests, staves, tuplets, beams and slurs in any score.

.. note:: 
    The Abjad documentation is a work in progress.
    

Start here

.. toctree::
    :maxdepth: 1

    chapters/start_here/abjad/index

Examples

.. toctree::
    :numbered:

    chapters/examples/bartok/index
    chapters/examples/ferneyhough/index
    chapters/examples/ligeti/index

Reference manual

.. toctree::
    :numbered:

    chapters/user_documentation/annotations/index
    chapters/user_documentation/chords/index
    chapters/user_documentation/comments/index
    chapters/user_documentation/containers/index
    chapters/user_documentation/instrument_marks/index
    chapters/user_documentation/lily_files/index
    chapters/user_documentation/measures/index
    chapters/user_documentation/notes/index
    chapters/user_documentation/pitch/named_chromatic_pitch/index
    chapters/user_documentation/rests/index
    chapters/user_documentation/scores/index
    chapters/user_documentation/spanners/index
    chapters/user_documentation/staves/index
    chapters/user_documentation/tuplets/index
    chapters/user_documentation/voices/index

Tutorials

.. toctree::
    :numbered:

    chapters/tutorials/time_signature_marks/index
    chapters/user_documentation/lcs/index
    chapters/user_documentation/parentage/index
    chapters/user_documentation/threads/index
    chapters/user_documentation/grobs/index
    chapters/user_documentation/understanding_overrides/index

Developer documentation

.. toctree::
    :numbered:

    chapters/developer_documentation/codebase/index
    chapters/developer_documentation/documentation/index
    chapters/developer_documentation/tests/index
    chapters/developer_documentation/scripts/index
    chapters/developer_documentation/optimization/timing/index
    chapters/developer_documentation/optimization/profiling/index
    chapters/developer_documentation/optimization/memory/index
    chapters/developer_documentation/optimization/class_attributes/index
    chapters/developer_documentation/optimization/slots/index
    chapters/developer_documentation/todo/index

Appendices

.. toctree::
    :numbered:
    :maxdepth: 1

    chapters/appendices/history/index
    chapters/appendices/lilypond/index
    chapters/appendices/midi_not_enough/index
    chapters/appendices/configuration/index
    chapters/appendices/input_output/index
    chapters/appendices/lilypond_multipliers/index
    chapters/appendices/lilypond_equivalencies/index
    chapters/appendices/coding_standards/index
    chapters/appendices/lists_of_numbers/index
    chapters/appendices/pitch_conventions/index
    chapters/appendices/pitch_deviation/index
    chapters/appendices/duration_conventions/index
    chapters/appendices/abjad_templates/index
    chapters/appendices/text_alignment/index
    chapters/appendices/abjad_book/index
    chapters/appendices/colors/index
    chapters/appendices/parallel_processing/index
    chapters/appendices/glossary/index
    chapters/appendices/bibliography/index
    chapters/appendices/versions/index
    chapters/appendices/whatnext/index

Abjad API
---------

.. toctree::
    :maxdepth: 2

    chapters/api/index

